@@ -1,7 +1,7 @@
 
 package OODoc::Text::Chapter;
 use vars '$VERSION';
-$VERSION = '0.04';
+$VERSION = '0.05';
 use base 'OODoc::Text::Structure';
 
 use strict;
@@ -11,12 +11,6 @@ use List::Util 'first';
 use Carp;
 
 
-#-------------------------------------------
-
-
-#-------------------------------------------
-
-
 sub init($)
 {   my ($self, $args) = @_;
     $args->{type}       ||= 'Chapter';
@@ -91,18 +85,4 @@ sub sections()
 
 #-------------------------------------------
 
-
-#-------------------------------------------
-
-sub allExamples()
-{   my $self = shift;
-
-    ( $self->examples
-    , map({$_->allExamples} $self->sections)
-    , map({$_->examples}    $self->subroutines)
-    );
-}
-
-#-------------------------------------------
-
 1;
