@@ -1,7 +1,7 @@
 
 package OODoc::Text::Section;
 use vars '$VERSION';
-$VERSION = '0.04';
+$VERSION = '0.05';
 use base 'OODoc::Text::Structure';
 
 use strict;
@@ -11,12 +11,6 @@ use Carp;
 use List::Util 'first';
 
 
-#-------------------------------------------
-
-
-#-------------------------------------------
-
-
 sub init($)
 {   my ($self, $args) = @_;
     $args->{type}      ||= 'Section';
@@ -31,6 +25,11 @@ sub init($)
 
 #-------------------------------------------
 
+
+sub chapter() { shift->container }
+
+#-------------------------------------------
+
 sub path()
 {   my $self = shift;
     $self->chapter->path . '/' . $self->name;
@@ -61,9 +60,6 @@ sub all($@)
 #-------------------------------------------
 
 
-#-------------------------------------------
-
-
 sub subsection($)
 {   my ($self, $thing) = @_;
 
@@ -91,23 +87,4 @@ sub subsections(;@)
 #-------------------------------------------
 
 
-#-------------------------------------------
-
-
-sub chapter() { shift->container }
-
-#-------------------------------------------
-
-
-#-------------------------------------------
-
-
-sub allExamples()
-{   my $self = shift;
-
-    ( $self->examples
-    , map {$_->examples} $self->subsections
-    );
-}
-
 1;
